LedRgb

Type Alias LedRgb 

pub type LedRgb = led_rgb;
Type alias for the Zephyr led_rgb struct used to describe a single pixel’s RGB value.

Note that led_strip_update_rgb is documented to potentially overwrite the pixel buffer, hence methods that update the strip take &mut [LedRgb].

Aliased Type

#[repr(C)]
pub struct LedRgb { pub r: u8, pub g: u8, pub b: u8, }

Fields

r: u8

Red channel

g: u8

Green channel

b: u8

Blue channel